<?php

namespace Teknisa\EST\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;

class Ger14600ComposicaoDoProduto extends \Teknisa\EST\Controllers\TeknisaCrud {
    
    protected $dataSourceName;
    protected $parameterBagColumns = array();
    
    public function __construct($crudService) {
        $this->crudService = $crudService;
        
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        
        try{
            
            
            $dataSource = substr($request->getRoutePath(), 1, strlen($request->getRoutePath()));
            $this->dataSourceName = $dataSource;
            
            switch ($dataSource) {
                case 'produto_composicao':
                    $this->parameterBagColumns = array("CDFILIAL", "P_PRODINI", "P_PRODFIN", "CDPRODUTO", "CDNVPRODUTO", "IDTIPOCOMPPROD", "CDSEGMER", "TODOS");
                    break;
                
                case 'rotfabrica_produto_departamento':
                    $this->parameterBagColumns = array("CDPRODUTO");
                    break;
                
                case 'rotlocal_produto_departamento':
                    $this->parameterBagColumns = array("CDPRODUTO", "CDFILIAL");
                    break;
                case 'prodgrupromoc_produto':
                    $this->parameterBagColumns = array("CDGRUPROMOC");
                    break;
                
                case 'gruppromocprod_grupopromoc':
                    $this->parameterBagColumns = array("CDPRODPROMOCAO");
                    break;
                    
                case 'grupromocprfil_grupopromoc':
                    $this->parameterBagColumns = array("CDPRODPROMOCAO", "CDFILIAL");
                    break;
                case 'desgrupromocpr_prodgrupromoc_produto':
                    $this->parameterBagColumns = array("CDPRODPROMOCAO", "CDGRUPROMOC");
                    break;
                case 'desgrupromprfil_prodgrupromoc_produto':
                    $this->parameterBagColumns = array("CDPRODPROMOCAO", "CDGRUPROMOC", "CDFILIAL");
                    break;
               
            }
            
            parent::find($request, $response);
        }
        catch(\Exception $e) {
            throw $e;
        }
    
    }
    
    public function save(DTO\Request $request, DTO\Response $response) {
        
        try{
            $dataSourceName = substr($request->getRoutePath(), 1, strlen($request->getRoutePath()) - 6);
          
            $this->dataSourceName = $dataSourceName;
            
          
            
            if($dataSourceName === 'rotfabrica_produto_departamento' 
                || 'gruppromocprod_grupopromoc' 
                || 'desgrupromocpr_prodgrupromoc_produto'
                || 'rotlocal_produto_departamento'
                || 'grupromocprfil_grupopromoc'
                || 'desgrupromprfil_prodgrupromoc_produto'
                || 'produtoadic_produto') {
                 
                $this->dataSourceName = explode("_", $dataSourceName)[0];
            }
            
            
            
            parent::save($request, $response);
        }
        catch(\Exception $e) {
            throw $e;
        }
    
    }
    
     public function delete(DTO\Request $request, DTO\Response $response) {
        
        try{
            $rota = substr($request->getRoutePath(), 1, strlen($request->getRoutePath()) - 8);
            $data = explode("_", $rota);
            $dataSource = $data[0];
            $filhos = false;
            $row = array();
            $primaryKeys = array();
      
            
            
            if($dataSource === 'grupromocprfil' || $dataSource === 'grupromoc' || $dataSource === 'grupromocprod'){
                $filhos = true;
            }
            //---------------------------Informa quais são as tabelas com registros filhos-----------------------//
            if($dataSource === 'grupromoc') {
                $dataSourceFilhos = array(array('name' => 'prodgrupromoc', 'filhos' => 'true'), 
                                          array('name' => 'grupromocprod', 'filhos' => 'false'),
                                          array('name' => 'grupromocprfil', 'filhos' => 'false'));
                $dataSourceFilhos[0]['dataSourceFilhos'] = 
                    array(array('name' => 'desgrupromocpr', 'filhos' => 'false'),
                          array('name' => 'desgrupromprfil', 'filhos' => 'false'));

            }
            
            if($dataSource === 'grupromocprod') $dataSourceFilhos = array(array('name' => 'desgrupromocpr', 'filhos' => 'false'));

            if($dataSource === 'grupromocprfil') $dataSourceFilhos = array(array('name' => 'desgrupromprfil', 'filhos' => 'false'));

            //-----------------------------------------------------------------------------------------------------//
            
            $row = $primaryKeys;
            if($filhos === true) {
               foreach($primaryKeys as $key) {
                    $requestGetRow = $request->getRow();
                    $row[$key] = $requestGetRow[$key];
               }
                $this->deleteFilhos($dataSourceFilhos, $primaryKeys, $row, $response);
            }

            $this->dataSourceName = $dataSource;
            parent::delete($request, $response);
    
            
        }
        catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function deleteFilhos($dataSourceFilhos, $primaryKeys, $row, $response) {
    // Deleta Filhos 
      
        // Percorre o vetor de dataSourceFilhos
        try {
            for($i =0; $i < count($dataSourceFilhos); $i++) {
                // Verifica se os filhos possuem filhos e chama o metado novamente caso tenham
                if($dataSourceFilhos[$i]['filhos'] === 'true') {
                    $this->deleteFilhos($dataSourceFilhos[$i]['dataSourceFilhos'], $primaryKeys, $row, $response);
                }
                
                $conditions = $this->crudService->getConditionsByColumns($primaryKeys, $row);
                       
                $dataSet = $this->crudService->getFilteredDataSet($dataSourceFilhos[$i]['name'], $conditions);
              
                $this->crudService->delete($response, $dataSet);
            }
        }
        catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function saveBlob(DTO\Request $request, DTO\Response $response) {
        
    	try{
            $row = $request->getRow();
            if (isset($row["TXROTFAB"])){
                    $row["TXROTFAB"] = bin2hex($row["TXROTFAB"]);
                    $this->dataSourceName = "descroteiro";
            } else {
                if (isset($row["TXROTFABLOC"])){
                    $row["TXROTFABLOC"] = bin2hex($row["TXROTFABLOC"]);
                    $this->dataSourceName = "descrotlocal";
                } else {
                    throw Exception("Row passada não possui campo BLOB");
                }
            }
            $newRequest = new DTO\Request\Row ($row, '', '', '');
    	    parent::save($newRequest, $response);
    	} catch(\Exception $e){
    	    $response->setError(new DTO\Response\Error($e->getMessage(),1));
    	}
    
    }
    
    
    
}