<?php

require_once 'base/FpaCalculofolhaEntityBase.php';


/**
 * FpacalculofolhaEntity.
 *
 * @package Entity
 * @author  alessandrobartels
 *
 */
class FpacalculofolhaEntity extends FpaCalculofolhaEntityBase
{

    private $itensCalculoFolha;

    /**
     * Retorna array de instancias da entidade Calculo Folha.
     *
     * @param integer    $nr_org             Numero da organizacao.
     * @param integer    $tipo_movimento     Numero do tipo de movimento.
     * @param TkDateTime $dt_ocorrencia      Instancia da classe TkDateTime.
     * @param integer    $nrTpModalidadeCalc Numero do tipo de modalidade de calculo.
     * @param integer    $nrOcorrenciaCalc   Numero de ocorrencia de calculo.
     *
     * @return array FpacalculofolhaEntity
     *
     * @author alessandrobartels -
     *         alessandrobartels - 20/12/2011 - adicionado parametros de tipo modalidade e ocorrencia de calculo.
     */
    public function retornaCalculoFolha(
        $nr_org, $tipo_movimento, $dt_ocorrencia, $nrTpModalidadeCalc, $nrOcorrenciaCalc
    ) {
        $calc_folha = Fpacalculofolha::retornaCalculoFolha(
            $nr_org, $tipo_movimento, $nrTpModalidadeCalc, $nrOcorrenciaCalc, $dt_ocorrencia, $dt_ocorrencia
        );

        if ($calc_folha === null) {
            $this->inserePersisteCalculoFolha($nr_org, $tipo_movimento, $nrTpModalidadeCalc, $nrOcorrenciaCalc, $dt_ocorrencia);
            $calc_folha = Fpacalculofolha::retornaCalculoFolha(
                $nr_org, $tipo_movimento, $nrTpModalidadeCalc, $nrOcorrenciaCalc, $dt_ocorrencia, $dt_ocorrencia
            );
        }

        return $calc_folha;
    }


    public function carregaListaNrCalculoFolhaTodasOcorrencias(
        $nrOrg, $tipoMovimento, TkDateTime $dtOcorrencia, $nrTpModalidadeCalc
    ){
        $calculosFolha = Fpacalculofolha::retornaCalculoFolhaTodasOcorrencias(
            $nrOrg, $tipoMovimento, $nrTpModalidadeCalc, $dtOcorrencia, $dtOcorrencia
        );

        $listaNrCalculo = array();

        foreach ($calculosFolha as $calculo){
            $listaNrCalculo[] = $calculo->getNrcalculofolha();
        }

        return $listaNrCalculo;
    }


    /**
     * Adiciona uma instancia de Calculo Folha na base.
     *
     * @param integer    $nr_org             Numero da organizacao.
     * @param integer    $tipo_movimento     Numero do tipo de movimento.
     * @param integer    $nrTpModalidadeCalc Numero do tipo de modalidade de calculo.
     * @param integer    $nrOcorrenciaCalc   Numero de ocorrencia de calculo.
     * @param TkDateTime $dt_ocorrencia      Instancia da classe TkDateTime.
     *
     * @return integer
     *
     * @author alessandrobartels -
     *         alessandrobartels - 20/12/2011 - adicionado parametros de tipo modalidade e ocorrencia de calculo.
     */
    public function inserePersisteCalculoFolha(
        $nr_org, $tipo_movimento, $nrTpModalidadeCalc, $nrOcorrenciaCalc,  $dt_ocorrencia
    ){

        /*$this->setNrorg($nr_org);
        $this->setNrtipomoviment($tipo_movimento);
        $this->setDtocorrencia($dt_ocorrencia);*/

        $item = new self();
        $item->setNrorg($nr_org);
        $item->setDtocorrencia($dt_ocorrencia);
        $item->setNrtipomoviment($tipo_movimento);
        $item->setNrtpmodalidcal($nrTpModalidadeCalc);
        $item->setNrocorrecal($nrOcorrenciaCalc);


        $item->persist();
        $nrItemCalculo = $item->getNrcalculofolha();
        unset($item);

        return $nrItemCalculo;
    }


    /**
     * Enter description here ...
     *
     * @param integer    $nr_org               Numero da Organizacao.
     * @param integer    $nr_tipo_movimento    Numero do Tipo de movimento.
     * @param TkDateTime $dt_inicial           Instancia da classe TkDateTime.
     * @param TkDateTime $dt_final             Instancia da classe TkDateTime.
     * @param integer    $nrTipoModalidadeCalc Numero do Tipo de Modalidade de Calculo.
     * @param integer    $nrOcorrenciaCalc     Numero de Ococrrencia de Calculo.
     *
     * @return string
     *
     * @author alessandrobartels
     *         alessandrobartels - 13/02/2012 - Parametrizado $nrTipoModalidadeCalc, $nrOcorrenciaCalc.
     */
    public function retornaCalculoFolhaPeriodo(
        $nr_org, $nr_tipo_movimento, TkDateTime $dt_inicial, TkDateTime $dt_final, $nrTipoModalidadeCalc,
        $nrOcorrenciaCalc
    ){

        $lista='';
        $calc_folha = Fpacalculofolha::retornaCalculoFolha(
            $nr_org, $nr_tipo_movimento, $nrTipoModalidadeCalc, $nrOcorrenciaCalc, $dt_inicial, $dt_final
        );
        
        foreach ($calc_folha as $calc) {
            $lista = $lista.$calc->getNrcalculofolha().',';
        }

        $lista = substr($lista, 0, strlen($lista)-1);
        return $lista;
    }


    public function retornaListaCalculoFolhaPorPeriodo(
        $nrOrg, $tipoMovimento, TkDateTime $dtInicial, TkDateTime $dtFinal, $nrTpModalidadeCalc
    ){
        $calculosFolha = Fpacalculofolha::retornaCalculoFolhaTodasOcorrencias(
            $nrOrg, $tipoMovimento, $nrTpModalidadeCalc, $dtInicial, $dtFinal
        );

        $listaNrCalculo = array();

        foreach ($calculosFolha as $calculo){
            $listaNrCalculo[$calculo->getNrcalculofolha()] = $calculo;
        }

        return $listaNrCalculo;
    }

    /*
    public function retornaCalculoFolhaPorNumero($nrOrg, $nrCalculoFolha){

        $resultado = FpaCalculofolha::retornaCalculoFolhaPorNumro($nrOrg, $nrCalculoFolha);
        return $resultado;
    }*/

    /**
     * @param $nrorg
     * @param $dtocorrencia
     * @param $nrtipomoviment
     * @param $nrtpmodalidadecalc
     * @param $nrocorrencal
     *
     * @autor jorgefonseca
     */
    public function insereCalculoFolha($nrorg, $dtocorrencia, $nrtipomoviment, $nrtpmodalidadecalc, $nrocorrencal) {
        $this->setNrorg($nrorg);
        $this->setDtocorrencia($dtocorrencia);
        $this->setNrtipomoviment($nrtipomoviment);
        $this->setNrtpmodalidcal($nrtpmodalidadecalc);
        $this->setNrocorrecal($nrocorrencal);
    }

    /**
     * @return array
     */
    public function getItensCalculoFolha() {
        if (!$this->itensCalculoFolha) {
            $this->itensCalculoFolha = FpaitecalcfolhaEntity::getItensCalculoFolha(
                $this->getNrorg(), $this->getNrcalculofolha()
            );
        }
        return $this->itensCalculoFolha;
    }

    public static function getCalculoFolha($nrorg, $nrtipomovimento, $nrmodalidade, $nrocorrecalc, $dtocorrencia) {
        $params = array($nrorg, $nrtipomovimento, $nrmodalidade, $nrocorrecalc, $dtocorrencia, $dtocorrencia);
        $fpacalculofolha = self::getEntityByWhere(
            'NRORG = ?
             AND NRTIPOMOVIMENT = ?
             AND NRTPMODALIDCAL = ?
             AND NROCORRECAL = ?
             AND (DTOCORRENCIA BETWEEN ? AND ?)', $params
        );
        return $fpacalculofolha;
    }

}

